##  5. How to block or delete cookies and local storage objects
You can control and manage cookies in different ways using your browser. You can delete all cookies on your device by clearing your browsing history. This will remove all cookies from all websites you have visited. Keep in mind that if you delete all cookies, the preferences you have stored will also be deleted. Also, for the “Essential” cookies and local storage objects, deletion might have an impact on certain functions of the product.
You can also delete all web storage objects saved on your device by following the instructions available through the links provided:
  * [Firefox![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.mozilla.org%2Fen-US%2Fkb%2Fhow-do-i-turn-do-not-track-feature "https://support.mozilla.org/en-US/kb/how-do-i-turn-do-not-track-feature")
  * [Internet Explorer![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.microsoft.com%2Fen-us%2Fhelp%2F17288%2Fwindows-internet-explorer-11-use-do-not-track "https://support.microsoft.com/en-us/help/17288/windows-internet-explorer-11-use-do-not-track")
  * [Microsoft Edge![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.microsoft.com%2Fen-us%2Fhelp%2F4027947%2Fmicrosoft-edge-delete-cookies "https://support.microsoft.com/en-us/help/4027947/microsoft-edge-delete-cookies")
  * [Chrome![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.google.com%2Fchrome%2Fanswer%2F114836%3Fhl%3Den%26ref_topic%3D3421433 "https://support.google.com/chrome/answer/114836?hl=en&ref_topic=3421433")
  * [Safari![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=http%3A%2F%2Fhelp.apple.com%2Fsafari%2Fmac%2F9.0%2F%23%2Fsfri40732 "http://help.apple.com/safari/mac/9.0/#/sfri40732")
  * [Opera![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=http%3A%2F%2Fhelp.opera.com%2FWindows%2F12.10%2Fen%2Fnotrack.html?locale=en-US&state=PRODUCTION&version=CLOUD "http://help.opera.com/Windows/12.10/en/notrack.html")


YesNo
Send
